@@ -1038,7 +1038,7 @@ schema_state_add_override (SchemaState  *state,
                            GError      **error)
 {
   SchemaState *parent;
-  KeyState *original;
+  KeyState *original = NULL;
 
   if (state->extends == NULL)
     {
@@ -1373,14 +1373,14 @@ start_element (GMarkupParseContext  *context,
         }
       else if (strcmp (element_name, "override") == 0)
         {
-          const gchar *name, *l10n, *context;
+          const gchar *name, *l10n, *str_context;
 
-          if (COLLECT (STRING,            "name",    &name,
-                       OPTIONAL | STRING, "l10n",    &l10n,
-                       OPTIONAL | STRING, "context", &context))
+          if (COLLECT (STRING, "name", &name,
+                       OPTIONAL | STRING, "l10n", &l10n,
+                       OPTIONAL | STRING, "context", &str_context))
             schema_state_add_override (state->schema_state,
                                        &state->key_state, &state->string,
-                                       name, l10n, context, error);
+                                       name, l10n, str_context, error);
           return;
         }
     }
@@ -1390,11 +1390,11 @@ start_element (GMarkupParseContext  *context,
     {
       if (strcmp (element_name, "default") == 0)
         {
-          const gchar *l10n, *context;
-          if (COLLECT (STRING | OPTIONAL, "l10n",    &l10n,
-                       STRING | OPTIONAL, "context", &context))
+          const gchar *l10n, *str_context;
+          if (COLLECT (STRING | OPTIONAL, "l10n", &l10n,
+                       STRING | OPTIONAL, "context", &str_context))
             state->string = key_state_start_default (state->key_state,
-                                                     l10n, context, error);
+                                                     l10n, str_context, error);
           return;
         }
 
